
TODO: TODO_51_14_50_19: ensure `tangent_token` always exists

Or maybe no? If yes, we may also need to have surrogate `prev_arg`, no?

At the moment, if cursor touches no tokens (e.g. "whatever |"), `tagent_token` stays unset.

This complicates checking some conditions.

Maybe we can say that `tangent_token` always exists - in cases when it touches nothing,
it is considered to be surrogate "" (empty string).

We already have similar concepts - see `surrogate_node_id_` and `surrogate_tree_leaf_`.
